@@ -12,12 +12,12 @@ After install the module, you can access the simple CLI by using::
 
   $ python -m yagt <query1> <query2> [-u username] [other options]
 
-The output will be saved to ``result.csv'' by default.  For more information
-about the options, please use ``python -m yagt -h'' for the help page.  See
-``LICENSE.txt'' for license agreement.
+The output will be saved to ``result.csv`` by default.  For more information
+about the options, please use ``python -m yagt -h`` for the help page.  See
+``LICENSE.txt`` for license agreement.
 """
 
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 
 __description__ = """Y's API for Google Trends."""
 
